# Copyright (c) 2007 Altera Corporation. All rights reserved.  

# Your use of Altera Corporation's design tools, logic functions and other 
# software and tools, and its AMPP partner logic functions, and any output files 
# any of the foregoing (including device programming or simulation files), and 
# any associated documentation or information are expressly subject to the terms 
# and conditions of the Altera Program License Subscription Agreement, Altera 
# MegaCore Function License Agreement, or other applicable license agreement, 
# including, without limitation, that your use is for the sole purpose of 
# programming logic devices manufactured by Altera and sold by Altera or its 
# authorized distributors.  Please refer to the applicable agreement for 
# further details.

if ( ! $?QUARTUS_QENV ) then
setenv QUARTUS_QENV 1
setenv QENV_STATUS 0

if ( ! $?QUARTUS_ROOTDIR ) then
	echo "You must set the QUARTUS_ROOTDIR environment variable"
	echo "to point to a valid Quartus II installation before"
	echo "sourcing this script!"
	exit
endif

##### Reset paths

# Save original paths we inherited from the caller
setenv QUARTUS_ORIG_PATH $PATH

# Save original library path if exists
if ( $?LD_LIBRARY_PATH ) then
	setenv QUARTUS_ORIG_LIBPATH $LD_LIBRARY_PATH
endif

# Reset paths to a basic setting
setenv PATH /usr/bin:/bin
setenv LD_LIBRARY_PATH /usr/lib

##### Add user's custom paths

if ( $?QUARTUS_INIT_PATH ) then
	setenv PATH ${QUARTUS_INIT_PATH}:$PATH
endif

if ( $?QUARTUS_INIT_LIBPATH ) then
	setenv LD_LIBRARY_PATH ${QUARTUS_INIT_LIBPATH}:$LD_LIBRARY_PATH
endif

##### Basic settings

if (! $?TMP) then
	setenv TMP /tmp
else if ( ! -d $TMP ) then
	setenv TMP /tmp
endif

# quartus doesn't support other languages
# so if LANG is set make sure its C
if ($?LANG) then
	if ("$LANG" != "C") setenv LANG C
endif
# if any LC_* variable is set, set LC_ALL to C to override
env | grep LC_ >& /dev/null
if ($status == 0) setenv LC_ALL C

setenv QUARTUS_BIT_TYPE 32
setenv UNAME_SYSTEM `uname -s`
setenv UNAME_REVISION `uname -r`
setenv UNAME_VERSION `uname -v`

if ( ! $?CMD_NAME) setenv CMD_NAME `basename $0`

##### Platform settings

if ($UNAME_SYSTEM == "SunOS") then
	setenv QUARTUS_PLATFORM solaris
	setenv PATCH_CMD "showrev -a"
	setenv AWK_CMD "nawk"
	setenv MIN_OS_REVISION 8
	setenv LD_BIND_NOW 1
	setenv SYSTEM_MEMORY "`/usr/sbin/prtconf | /bin/grep Memory | /usr/bin/sed -e 's/Memory size: \([0-9]*\).*/\1/'`"
	if (`isainfo -b` == "64") then
		setenv QUARTUS_BIT_TYPE 64
	endif
	setenv SOLARIS_REVISION `uname -r | sed -e 's/5\.//g'`
	# We used to use these for Mainwin, but now they cause Quartus to hang, so make sure they are not set
	unsetenv MWNO_RIT
	unsetenv MWDONT_XINITTHREAD

	if ( `expr $SOLARIS_REVISION \< $MIN_OS_REVISION` ) then
		echo "You must run the Quartus II software under an operating"
		echo "system of version $QUARTUS_PLATFORM $MIN_OS_REVISION or later."
		setenv QENV_STATUS -2
		exit
	endif
else if ($UNAME_SYSTEM == "Linux") then
	setenv QUARTUS_PLATFORM linux
	setenv PATCH_CMD ""
	setenv AWK_CMD "awk"
	setenv MWRT_MODE classic
	if ( $?LC_CTYPE ) then
		if ( $LC_CTYPE == "POSIX" ) then
			setenv LC_CTYPE en_US
		endif
		if ( $LC_CTYPE == "C" ) then
			setenv LC_CTYPE en_US
		endif
	else
		unsetenv LC_ALL
		setenv LC_CTYPE en_US
	endif

	# Memory manager crashes if LD_ASSUME_KERNEL is used:
	unsetenv LD_ASSUME_KERNEL

	# We want to check if we are running on a supported version of Red Hat Linux (8.0, RHEL3).
	# If not, we set the MWWM environment variable to put Mainwin into compatibility mode
	# for better interaction with non-supported distributions. Users can turn this on 
	# as well by setting the QUARTUS_MWWM env. variable to allwm.
	if ( -f /etc/redhat-release ) then
		setenv REDHAT_VERSION `cat /etc/redhat-release | grep release | sed -e 's/Red Hat Linux release //g' -e 's/(.*//g'`
		if ( "$REDHAT_VERSION" =~ *Red?Hat?Enterprise* ) then
			if ("$REDHAT_VERSION" =~ *release?3 ) setenv REDHAT_VERSION 3.0rhel
			if ("$REDHAT_VERSION" =~ *release?4 ) setenv REDHAT_VERSION 4.0rhel
			if ("$REDHAT_VERSION" =~ *release?5* ) setenv REDHAT_VERSION 5.0rhel
		endif

		if ( "$REDHAT_VERSION" =~ *Fedora?Core* ) then
			if ("$REDHAT_VERSION" =~ *release?4 ) setenv REDHAT_VERSION 4.0rhel
		endif

		if ( "$REDHAT_VERSION" =~ *CentOS* ) then
			if ("$REDHAT_VERSION" =~ *release?4* ) setenv REDHAT_VERSION 4.0rhel
			if ("$REDHAT_VERSION" =~ *release?5* ) setenv REDHAT_VERSION 5.0rhel
		endif

		if ( "$REDHAT_VERSION" == "3.0rhel" || "$REDHAT_VERSION" == "4.0rhel" || "$REDHAT_VERSION" == "5.0rhel" ) then
			# do nothing
		else
			# Go into window compatibility mode (allwm mode)
			if (! $?QUARTUS_MWWM ) then
				setenv MWWM allwm
			endif
		endif
	else if ( -f /etc/issue ) then
		setenv SUSE_VERSION `cat /etc/issue | grep 'SUSE' | sed -e 's/Welcome to //g' -e 's/ (.*//g'`
		if ( "$SUSE_VERSION" == "SUSE LINUX Enterprise Server 9" || "$SUSE_VERSION" == "SUSE LINUX Enterprise Desktop 9" ) then
			# Supported, don't set MWWM
		else if ( "$SUSE_VERSION" == "SUSE Linux Enterprise Server 10" || "$SUSE_VERSION" == "SUSE Linux Enterprise Desktop 10" ) then
			# Supported, don't set MWWM
		else
			# This is the case for a non-supported Linux distribution.  We don't prevent Quartus II
			# from running on this distribution, but we don't do anything special either. Individual
			# users may need to set QUARTUS_MWWM as needed.
			if (! $?QUARTUS_MWWM ) then
				setenv MWWM allwm
			endif
		endif
	else
		# This is the case for a non-supported Linux distribution.  We don't prevent Quartus II
		# from running on this distribution, but we don't do anything special either. Individual
		# users may need to set QUARTUS_MWWM as needed.
		if (! $?QUARTUS_MWWM ) then
			setenv MWWM allwm
		endif
	endif
	
	if (`uname -m` == "x86_64") then
		setenv QUARTUS_BIT_TYPE 64
	endif

	# We don't support processors without SSE extensions (e.g. Pentium II and older CPUs).
	set cpumodel=`grep 'model name' /proc/cpuinfo | sed -e's/model name.*: //g' | uniq`
	grep sse /proc/cpuinfo >& /dev/null
	if ($status != 0) then
		echo ""
		echo "The Quartus II software is optimized for the Intel Pentium III processor"
		echo "and newer processors.  The required extensions were not found on:"
		echo "'$cpumodel'"
		echo ""
		echo "The Quartus II software will not function properly on this processor model."
		echo "Terminating..."
		setenv QENV_STATUS -1
	endif
	
	set QTB_CPU_FREQ=`cat /proc/cpuinfo | grep "cpu MHz" | cut -c 12-18 | uniq`
   
else
	echo "This operating system platform is unsupported by the Quartus II software."
	setenv QENV_STATUS -1
	exit
endif

##### Check if should be using 64-bit processing

unsetenv USE_64BIT 
# This will only happen for quartus_fit, quartus_tan or quartus_map on 64-bit systems
if ( $QUARTUS_BIT_TYPE == "64" && -f $QUARTUS_ROOTDIR/${QUARTUS_PLATFORM}64/$CMD_NAME ) then
	if ( "$CMD_NAME" == "jtagd" ) then
		setenv USE_64BIT
	else if ($?QUARTUS_64BIT) then
		if ($QUARTUS_64BIT != "0") then
			setenv USE_64BIT
		endif
	endif
endif

##### Mainwin setup

# If 64-bit flag is not set or this is a 32-bit operation system,
# setup the Mainwin/UI environment for 32-bit executables
if ( $?QUARTUS_MWHOME ) then
	setenv MWHOME $QUARTUS_MWHOME
else
	if ( ! $?USE_64BIT || $QUARTUS_BIT_TYPE == "32" ) then
		setenv MWHOME $QUARTUS_ROOTDIR/mw
	else if ( $?USE_64BIT && $QUARTUS_BIT_TYPE == "64" ) then
		setenv MWHOME $QUARTUS_ROOTDIR/mw64
	endif
endif

# If no mainwin home we are probably the qt-only web edition
if ( -d $MWHOME ) then

	# Need to unset MWCURRENT_LIBPATH so environment gets initialized from scratch
	if ($?MWCURRENT_LIBPATH) then
		unsetenv MWCURRENT_LIBPATH
	endif
	
	if ( -f $MWHOME/setupmainwin.csh && ! $?MWRELEASE) then
		source $MWHOME/setupmainwin.csh
	else
		source $MWHOME/setmwruntime.csh
	endif
	
	if ( $?QUARTUS_MWWM ) then
		setenv MWWM $QUARTUS_MWWM
	endif
	
	setenv MWUSE_FIXED_SCREENDPI 1
	setenv MWUSE_MOTIF_CLIPBOARD 1
	
	# this makes Quartus shared memory segment unique
	if (! $?QUARTUS_NO_SHM_KEY) then
		set id=`id`
		set id=`echo $id | sed -e 's/uid=//g' -e 's/(.*//g'`
		setenv MWSHM_KEY `expr 10000 + $$ + $id`
	endif
	
	if ( ! $?USE_64BIT || $QUARTUS_BIT_TYPE == "32" ) then
		setenv OBJ_STUDIO_HOME $QUARTUS_ROOTDIR/stingray
	   	setenv LD_LIBRARY_PATH $OBJ_STUDIO_HOME/lib-${MWOS}_optimized:$LD_LIBRARY_PATH
	else if ( $?USE_64BIT && $QUARTUS_BIT_TYPE == "64" ) then
		setenv OBJ_STUDIO_HOME $QUARTUS_ROOTDIR/stingray64
		setenv LD_LIBRARY_PATH $OBJ_STUDIO_HOME/lib-${MWCONFIG_NAME}_optimized:$LD_LIBRARY_PATH
	endif
	
	if ($?QUARTUS_MWREGISTRY) then
		setenv MWREGISTRY $QUARTUS_MWREGISTRY
	else
	    setenv MWREGISTRY $HOME/.mw/q2_registry_${MWCONFIG_NAME}.bin:$HOME/.mw/q2_registry_hkcu_${MWCONFIG_NAME}.bin
	endif

endif

##### Quartus path setup

setenv PATH $QUARTUS_ROOTDIR/${QUARTUS_PLATFORM}:$PATH
setenv LD_LIBRARY_PATH $QUARTUS_ROOTDIR/${QUARTUS_PLATFORM}:$LD_LIBRARY_PATH

# If 64-bit flag is set and this system is 64-bit capable then setup environment to run 64-bit
if ($?USE_64BIT && $QUARTUS_BIT_TYPE == "64") then   
	setenv PATH $QUARTUS_ROOTDIR/${QUARTUS_PLATFORM}64:$PATH
	setenv LD_LIBRARY_PATH $QUARTUS_ROOTDIR/${QUARTUS_PLATFORM}64:$LD_LIBRARY_PATH
endif

# Add <qdir>/adm to path, it has some helper tools
setenv PATH $QUARTUS_ROOTDIR/adm:$PATH
# On solaris, we have some OS specific system libs we need
if ( $QUARTUS_PLATFORM == "solaris" ) then
	setenv LD_LIBRARY_PATH $QUARTUS_ROOTDIR/adm/syslibs/${UNAME_REVISION}:$LD_LIBRARY_PATH
endif

setenv TCL_LIBRARY $QUARTUS_ROOTDIR/$QUARTUS_PLATFORM/tcl8.4

if (-f $QUARTUS_ROOTDIR/adm/qtb.csh) then
	source $QUARTUS_ROOTDIR/adm/qtb.csh
endif

if (! -d $QUARTUS_ROOTDIR/$QUARTUS_PLATFORM ) then
	echo "*** The Quartus II software cannot be started because the current platform,"
	echo "    '$QUARTUS_PLATFORM', does not appear to be installed in:"
	echo "    '$QUARTUS_ROOTDIR'."
	echo ""
	setenv QENV_STATUS -1
else
	setenv PROC_ID `getpid`
endif 

# endif for "if ( ! $?QUARTUS_QENV ) then"
endif
